# spyral-utils Documentation

spyral-utils is a collection of useful functionality originally developed for the [Spyral](https://github.com/ATTPC/Spyral/) AT-TPC analysis library. During Spyral's development it was realized that this functionality would be desirable even once the work with Spyral was done, so the code was extracted an developed into it's own python package relased on PyPI. spyral-utils is is still part of Spyral, but can be used in other projects and codes as well.
